@@ -121,6 +121,11 @@ class DetectionResult:
             return None
 
         trace = traceback.format_tb(exception.__traceback__)
+
+        if len(trace) == 0:
+            # an exception might not have a trace back if it was not raised
+            return str(exception)
+
         # we only take last element of trace which will show the
         # detection file name and line of the error, for example:
         #    division by zero: AlwaysFail.py, line 4, in detection 1/0
