@@ -62,11 +62,7 @@ class ExecutionMatch:
 
     @property
     def errored(self) -> bool:
-        return (
-            self.alert_type == ERROR_TYPE_RULE
-            or self.alert_type == ERROR_TYPE_SCHEDULED_RULE
-            or self.alert_type == ERROR_TYPE_POLICY
-        )
+        return self.alert_type in (ERROR_TYPE_RULE, ERROR_TYPE_SCHEDULED_RULE, ERROR_TYPE_POLICY)
 
     @classmethod
     def from_json(cls, data: Dict[str, Any]) -> Optional[ExecutionMatch]:
