@@ -57,7 +57,7 @@ class FilterConditionBase:
 
     @staticmethod
     def is_valid_dict(data: Dict) -> bool:
-        return data.get("target", None) is not None and data.get("operator", None) is not None
+        return data.get("target", None) and data.get("operator", None)
 
 
 class FilterOperator(ABC):  # pylint: disable=too-few-public-methods
@@ -85,21 +85,10 @@ class FilterCondition(FilterConditionBase):
         if is_simple_key(self.target):
             # if target is simple (ie. not a jmespath expression) we can access the
             # property of the event directly, avoiding jmespath overhead
-            # KeyError is raised here if the key doesn't exist, which causes the
-            # higher-level Filter implementation to return True (as if the filter
-            # was skipped)
-            self.compiled_path = lambda obj: obj[self.target]
+            self.compiled_path = lambda x: x.get(self.target)
         else:
             # use jmespath whenever a more complex expression is detected
-            jmespath_compiled_search = jmespath.compile(self.target).search
-
-            def jmespath_search(obj: Any) -> Any:
-                result = jmespath_compiled_search(obj)
-                if result is None:
-                    raise KeyError
-                return result
-
-            self.compiled_path = jmespath_search
+            self.compiled_path = jmespath.compile(self.target).search
         self.value_is_list = is_list(self.value)
         self.target_is_ip = self.target_type_hint == "ip"
 
@@ -500,10 +489,7 @@ class Filter:  # pylint: disable=too-few-public-methods
     def filter(self, event: Any) -> bool:
         if self.exception:
             raise self.exception
-        try:
-            return self._compiled_filter(event)
-        except KeyError:
-            return True
+        return self._compiled_filter(event)
 
     def total_conditions(self) -> int:
         total = 0
@@ -520,11 +506,6 @@ class Filter:  # pylint: disable=too-few-public-methods
         return total
 
     def __init__(self, info: Dict):
-        if FilterCondition.is_valid_dict(info):
-            self.condition = FilterCondition.from_dict(info)
-        else:
-            self.condition = None
-
         self.nots = []
         self.ors = []
         self.ands = []
@@ -536,6 +517,23 @@ class Filter:  # pylint: disable=too-few-public-methods
         for i in info.get("or", []):
             self.ors.append(Filter(i))
 
+        if FilterCondition.is_valid_dict(info):
+            # FilterCondition.is_valid_dict checks for the target and operation fields.
+            # If those are set, this is a target / operator / value filter, so the
+            # fields (and, or, not) won't be evaluated, only this condition will be.
+            # So, if any of those fields are set, this filter will raise an exception,
+            # avoiding potential confusion (otherwise the and/or/not fields would be
+            # silently ignored).
+            if len(self.ands) > 0 or len(self.ors) > 0 or len(self.nots) > 0:
+                self.exception = self._too_many_clauses_exception()
+            self.condition = FilterCondition.from_dict(info)
+        else:
+            if info.get("target") or info.get("operator"):
+                self.exception = FilterException(
+                    "a condition statement requires both target and operator to be set"
+                )
+            self.condition = None
+
         try:
             self._compiled_filter = self.__compile()
         except Exception as e:  # pylint: disable=invalid-name,broad-except
@@ -570,16 +568,29 @@ class Filter:  # pylint: disable=too-few-public-methods
         return _not
 
     def __compile(self) -> Callable[[Any], bool]:
-        if self.condition is not None:
+        if self.condition:
             return get_compare_fn(self.condition)
 
         if len(self.ors) > 0:
+            if len(self.nots) > 0 or len(self.ands) > 0:
+                self.exception = self._too_many_clauses_exception()
             return self._compiled_or_fn()
 
         if len(self.ands) > 0:
+            if len(self.nots) > 0:
+                self.exception = self._too_many_clauses_exception()
             return self._compiled_and_fn()
 
         if len(self.nots) > 0:
             return self._compiled_not_fn()
 
-        return lambda x: False
+        # If this is an empty filter structure, the filter is a no-op.
+        # In detection filtering, this == a True result, since we want to
+        # err/fail on the safe side: not excluding an event from alerts.
+        return lambda x: True
+
+    def _too_many_clauses_exception(self) -> Exception:
+        return FilterException(
+            "a statement may set at most one of condition "
+            "(target/operator/value), and, or, & not"
+        )
